#include <cuda_runtime.h>
#include <cutil.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "my_me_gpu.h"

int main( int argc, char* argv[] )
{
	// frame
	int width = 1920;
	int height = 1088;
	int pitch = width;
	int nbFrames = 2;
	unsigned int widthInMBs = 120;
	unsigned int heightInMBs = 68;

	unsigned char* refFrame = new unsigned char[ width*height ];
	memset( refFrame, 1, width*height*sizeof(unsigned char) );
	
	unsigned char* curFrame = new unsigned char[ width*height ];
	memset( curFrame, 2, width*height*sizeof(unsigned char) );

	// GPU
	CUT_DEVICE_INIT( argc, argv );
	init( width, height );

	// MB
	unsigned int uNumMBs = 8160;
	unsigned int mbWidth = 16;

	// frame infos
	sFrameInfos currFrameInf;
	currFrameInf.uNumMBs = uNumMBs;
	currFrameInf.pitchPixels = pitch;
	currFrameInf.frameHeight = height;
	currFrameInf.widthInMBs = widthInMBs;
	currFrameInf.heightInMBs = heightInMBs;
	sMBInfos* mbTab_cpu = new sMBInfos[ uNumMBs ];

	// boucle
	for( int idx = 0; idx < nbFrames; idx++ )
	{
		// encode
		printf( "\n******** New frame ************* \n" );

		int offset = 0;
		unsigned int uMB = 0;

		// loop over all MBs in the picture
		for( unsigned int uMBRow = 0; uMBRow < heightInMBs; uMBRow++ )
		{
			for( unsigned int uMBCol = 0; uMBCol < widthInMBs; uMBCol++, uMB++ )
			{
				mbTab_cpu[ uMB ].uMB = uMB;
				mbTab_cpu[ uMB ].uMBx = uMBCol;
				mbTab_cpu[ uMB ].uMBy = uMBRow;
				mbTab_cpu[ uMB ].offset = offset;

				offset += 16;
			}

			offset += pitch*mbWidth - widthInMBs*mbWidth;
		}

		// GPU
		compute( &currFrameInf, mbTab_cpu, pitch, height, refFrame, curFrame );
	}

	destroy();
	CUT_EXIT(argc, argv);

	return 0;
}
