#include "my_me_kernel.h"
#include "my_me_gpu.h"

#include <stdio.h>
#include <stdlib.h>
#include <cutil.h>

unsigned int gtimer;

void init( int w, int h )
{
	CUT_SAFE_CALL( cutCreateTimer( &gtimer ) );
	
	setupGPUFrames( w, h );
}

void resetAndStartTime( unsigned int timer )
{
	CUT_SAFE_CALL( cutResetTimer( timer ) );
	CUT_SAFE_CALL( cutStartTimer( timer ) );
}

void stopTimer( unsigned int timer )
{
	CUT_SAFE_CALL( cutStopTimer( gtimer ) );
}

float getTimerValue( unsigned int timer )
{
	return cutGetTimerValue( timer );
}

void compute( sFrameInfos* fInfos, sMBInfos* mbTab_cpu, int w, int h, unsigned char* refdata, unsigned char* curdata )
{
	copyFramesToGPU( w, h, refdata, curdata );
	copyFrameInfosToGPU( fInfos, mbTab_cpu );
	
	CUT_SAFE_CALL( cutResetTimer( gtimer ) );
	CUT_SAFE_CALL( cutStartTimer( gtimer ) );
	doME_GPU(fInfos);
	CUT_SAFE_CALL( cutStopTimer( gtimer ) );
	getFrameInfosFromGPU( fInfos, mbTab_cpu );

	printf( "[GPU]Time to ME a slice : %.5fms\n", cutGetTimerValue( gtimer ) );
	printf( "MB #2011 : 16x16 : %d %d\n", mbTab_cpu[2011].res16x16.MVx, mbTab_cpu[2011].res16x16.MVy );
	printf( "\n" );
}

void destroy()
{
	deleteGPUFrames();
}
